Method: Color::GrayScale#-

Defined in:
lib/atome/utilities/color_helper/color/grayscale.rb

#-(other) ⇒ Object

Subtracts another colour to the current colour. The other colour will be converted to grayscale before subtraction. This conversion depends upon a #to_grayscale method on the other colour.

The subtraction is done using the grayscale accessor methods to ensure a valid colour in the result.



177
178
179
# File 'lib/atome/utilities/color_helper/color/grayscale.rb', line 177

def -(other)
  self + (-other)
end